Language
--------

It is used parameter to indicate response language.

.. list-table::
    :header-rows: 1
    
    * - Parameter name
      - value
      - default

    * - lang
      - en
      - en [#f1]_
      
.. rubric:: Footnotes

.. [#f1] The default value is the first order LANGUAGES from *settings/base.py*